local grafana = import 'grafonnet/grafana.libsonnet';
local dashboard = grafana.dashboard;
local row = grafana.row;
local template = grafana.template;
local logPanel = grafana.logPanel;
local bargaugePanel = grafana.bargaugePanel;
local singlestat = grafana.singlestat;
local prometheus = grafana.prometheus;
local panel = import 'panels_common.jsonnet';
 
 grafana.dashboard.new(
     title='Loki-Logs-dashboard',
     uid='loki123',
     editable=true,
     # Display metrics over the last 30 minutes
     time_from='now-72h',
     
 ).addPanel(
     grafana.logPanel.new(
         title='Test Logs-Filtered',
         # Direct queries to the `Prometheus` data source
         datasource='Loki',
         time_from='now-72h',
        time_shift=null,
        showLabels=false,
        showTime=true,
        sortOrder='Descending',
        wrapLogMessage=true,
        span=12,
        height=null,
     ).addTarget(
         grafana.prometheus.target(
             # Query 'server_pending_requests' from datasource
             expr='{filename="/var/log/system.log",job="grafana3"} |= "ASL Sender Statistics"',
             # Label query results as 'alias'
             # (corresponds to specific instances in the application cluster)
             legendFormat='{{database}}',
         )
     ),
     gridPos = { h: 16, w: 16, x: 0, y: 0 }
 ).addPanel(
     grafana.logPanel.new(
         title='Grafana Logs-Filtered',
         # Direct queries to the `Prometheus` data source
         datasource='Loki',
         time_from='now-120h',
        time_shift=null,
        showLabels=false,
        showTime=true,
        sortOrder='Descending',
        wrapLogMessage=true,
        span=12,
        height=null,
     ).addTarget(
         grafana.prometheus.target(
             # Query 'server_pending_requests' from datasource
             expr='{filename="/var/log/grafana.log", job="grafana3"} |= `level=warn msg`',
             # Label query results as 'alias'
             # (corresponds to specific instances in the application cluster)
             legendFormat='{{database}}',
         )
     ),
     gridPos = { h: 16, w: 16, x: 16, y: 0 }
 ).addTemplate(
  grafana.template.datasource(
    'Loki',
    'loki',
    'Loki',
    hide='label',
  )
)
 .addTemplate(
     template.new(
    'application',
    '$Loki',
    'label_values(application)',
    label='Application',
    refresh='time',
     )
    )
    .addTemplate(
  template.new(
    'instance',
    '$Loki',
    'label_values(jvm_memory_used_bytes{application="$application"}, instance)',
    label='Instance',
    refresh='time',
  )
  )