local grafana = import 'grafonnet/grafana.libsonnet';
local dashboard = grafana.dashboard;
local row = grafana.row;
local template = grafana.template;
local graphPanel = grafana.graphPanel;
local singlestat = grafana.singlestat;
local prometheus = grafana.prometheus;
local guagePanel = grafana.gaugePanel;


grafana.dashboard.new(
  'Rabbit-MQ Dashboard for Grafana',
  refresh='1m',
  editable=true,
  uid='4d8NM7BVz',
  time_from='now-12h'
)
.addTemplate(
  grafana.template.datasource(
    'server',
    'prometheus',
    'Prometheus',
    label='Server'
  )
)
.addTemplate(
  template.new(
    'Job',
    '$server',
    'label_values(process_max_fds, job)',
    label='Job',
    refresh='time',
  )
).addRow(
   row.new(
      title='Server resource overview',
      height='125px',
   )
   .addPanel(
     singlestat.new(
      'rabbit-mq message stats',
       span=4,
       valueName='current',
     )
     .addTarget(
       prometheus.target(
         'process_max_fds{job=~"$Job"}',
         datasource='$server',
       )
     )
   )
     .addPanel(
       guagePanel.new(
        title = "Guage panel to measure rabbit-mq memory",
        transparent=false,
        allValues=false,
        reducerFunction='mean',
        showThresholdLabels=false,
        showThresholdMarkers=true,
        unit='percent',
        min=0,
        max=1000000000,
        thresholdsMode='absolute',
        repeatDirection='h',
        pluginVersion='7',
        )
       .addTarget(
         prometheus.target(
           'process_virtual_memory_bytes{job=~"$Job"}',
           format='bytes',
           datasource='$server',
         )
       )
     )
 ).addRow(
     row.new(
        title='Queues progress',
        height='125px',
     )
     .addPanel(
         guagePanel.new(
          title = "Number of Queues present",
          transparent=false,
          allValues=false,
          reducerFunction='mean',
          showThresholdLabels=false,
          showThresholdMarkers=true,
          unit='count',
          min=0,
          max=100,
          thresholdsMode='absolute',
          repeatDirection='h',
          pluginVersion='7',
          datasource='Prometheus',
          )
         .addTarget(
           grafana.prometheus.target(
             # Query 'rabbitmq_queues' from datasource
             expr='rabbitmq_queues',
             legendFormat='Total Queues',
             )
         )
       ).addPanel(singlestat.new(
                  'Rabbit-MQ total number of queue reduction',
                   span=4,
                   valueName='current',
                    ).addTarget(
                         prometheus.target(
                           'rabbitmq_queue_reductions_total{job=~"rabbit-mq"}',
                           datasource='$server',
                         )
                   )
               )
   )
